# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['dash_mdc_neptune', 'dash_mdc_neptune.themes']

package_data = \
{'': ['*'], 'dash_mdc_neptune.themes': ['static/*']}

install_requires = \
['dash>=1.15.0']

setup_kwargs = {
    'name': 'dash-mdc-neptune',
    'version': '0.1.1',
    'description': 'Dash Material Design components for the Neptune platform.',
    'long_description': "# dash-mdc-neptune\n\ndash-mdc-neptune is a Dash component library.\n\nBoostrapped by https://github.com/plotly/dash-component-boilerplate\n\nGet started with:\n1. Install Dash and its dependencies: https://dash.plotly.com/installation\n2. Run `python usage.py`\n3. Visit http://localhost:8050 in your web browser\n\n## Contributing\n\nSee [CONTRIBUTING.md](./CONTRIBUTING.md)\n\n### Install dependencies\n\nIf you have selected install_dependencies during the prompt, you can skip this part.\n\n1. Install npm packages\n    ```\n    $ npm install\n    ```\n2. Create a virtual env and activate.\n    ```\n    $ virtualenv venv\n    $ . venv/bin/activate\n    ```\n    _Note: venv\\Scripts\\activate for windows_\n\n3. Install python packages required to build components.\n    ```\n    $ pip install -r requirements.txt\n    ```\n4. Install the python packages for testing (optional)\n    ```\n    $ pip install -r tests/requirements.txt\n    ```\n\n### Write your component code in `src/lib/components/DashMdcNeptune.react.js`.\n\n- The demo app is in `src/demo` and you will import your example component code into your demo app.\n- Test your code in a Python environment:\n    1. Build your code\n        ```\n        $ npm run build\n        ```\n    2. Run and modify the `usage.py` sample dash app:\n        ```\n        $ python usage.py\n        ```\n- Write tests for your component.\n    - A sample test is available in `tests/test_usage.py`, it will load `usage.py` and you can then automate interactions with selenium.\n    - Run the tests with `$ pytest tests`.\n    - The Dash team uses these types of integration tests extensively. Browse the Dash component code on GitHub for more examples of testing (e.g. https://github.com/plotly/dash-core-components)\n- Add custom styles to your component by putting your custom CSS files into your distribution folder (`dash_mdc_neptune`).\n    - Make sure that they are referenced in `MANIFEST.in` so that they get properly included when you're ready to publish your component.\n    - Make sure the stylesheets are added to the `_css_dist` dict in `dash_mdc_neptune/__init__.py` so dash will serve them automatically when the component suite is requested.\n- [Review your code](./review_checklist.md)\n\n### Create a production build and publish:\n\n1. Build your code:\n    ```\n    $ npm run build\n    ```\n2. Create a Python distribution\n    ```\n    $ python setup.py sdist bdist_wheel\n    ```\n    This will create source and wheel distribution in the generated the `dist/` folder.\n    See [PyPA](https://packaging.python.org/guides/distributing-packages-using-setuptools/#packaging-your-project)\n    for more information.\n\n3. Test your tarball by copying it into a new environment and installing it locally:\n    ```\n    $ pip install dash_mdc_neptune-0.0.1.tar.gz\n    ```\n\n4. If it works, then you can publish the component to NPM and PyPI:\n    1. Publish on PyPI\n        ```\n        $ twine upload dist/*\n        ```\n    2. Cleanup the dist folder (optional)\n        ```\n        $ rm -rf dist\n        ```\n    3. Publish on NPM (Optional if chosen False in `publish_on_npm`)\n        ```\n        $ npm publish\n        ```\n        _Publishing your component to NPM will make the JavaScript bundles available on the unpkg CDN. By default, Dash serves the component library's CSS and JS locally, but if you choose to publish the package to NPM you can set `serve_locally` to `False` and you may see faster load times._\n\n5. Share your component with the community! https://community.plotly.com/c/dash\n    1. Publish this repository to GitHub\n    2. Tag your GitHub repository with the plotly-dash tag so that it appears here: https://github.com/topics/plotly-dash\n    3. Create a post in the Dash community forum: https://community.plotly.com/c/dash\n\n#\n# Code Review Checklist\n\n## Code quality & design\n\n-   Is your code clear? If you had to go back to it in a month, would you be happy to? If someone else had to contribute to it, would they be able to?\n\n    A few suggestions:\n\n    -   Make your variable names descriptive and use the same naming conventions throughout the code.\n\n    -   For more complex pieces of logic, consider putting a comment, and maybe an example.\n\n    -   In the comments, focus on describing _why_ the code does what it does, rather than describing _what_ it does. The reader can most likely read the code, but not necessarily understand why it was necessary.\n\n    -   Don't overdo it in the comments. The code should be clear enough to speak for itself. Stale comments that no longer reflect the intent of the code can hurt code comprehension.\n\n*   Don't repeat yourself. Any time you see that the same piece of logic can be applied in multiple places, factor it out into a function, or variable, and reuse that code.\n*   Scan your code for expensive operations (large computations, DOM queries, React re-renders). Have you done your possible to limit their impact? If not, it is going to slow your app down.\n*   Can you think of cases where your current code will break? How are you handling errors? Should the user see them as notifications? Should your app try to auto-correct them for them?\n\n## Component API\n\n-   Have you tested your component on the Python side by creating an app in `usage.py` ?\n\n    Do all of your component's props work when set from the back-end?\n\n    Should all of them be settable from the back-end or are some only relevant to user interactions in the front-end?\n\n-   Have you provided some basic documentation about your component? The Dash community uses [react docstrings](https://github.com/plotly/dash-docs/blob/master/tutorial/plugins.py#L45) to provide basic information about dash components. Take a look at this [Checklist component example](https://github.com/plotly/dash-core-components/blob/master/src/components/Checklist.react.js) and others from the dash-core-components repository.\n\n    At a minimum, you should describe what your component does, and describe its props and the features they enable.\n\n    Be careful to use the correct formatting for your docstrings for them to be properly recognized.\n\n## Tests\n\n-   The Dash team uses integration tests extensively, and we highly encourage you to write tests for the main functionality of your component. In the `tests` folder of the boilerplate, you can see a sample integration test. By launching it, you will run a sample Dash app in a browser. You can run the test with:\n    ```\n    python -m tests.test_render\n    ```\n    [Browse the Dash component code on GitHub for more examples of testing.](https://github.com/plotly/dash-core-components)\n\n## Ready to publish? Final scan\n\n-   Take a last look at the external resources that your component is using. Are all the external resources used [referenced in `MANIFEST.in`](https://github.com/plotly/dash-docs/blob/0b2fd8f892db720a7f3dc1c404b4cff464b5f8d4/tutorial/plugins.py#L55)?\n\n-   [You're ready to publish!](https://github.com/plotly/dash-component-boilerplate/blob/master/%7B%7Bcookiecutter.project_shortname%7D%7D/README.md#create-a-production-build-and-publish)\n",
    'author': 'Noos Energy',
    'author_email': 'contact@noos.energy',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/noosenergy/dash-mdc-neptune',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
